@@ -1,4 +1,3 @@
-__version__ = "0.7.0"
 """
 :mod:`tobler` --- A library for spatial interpolation
 =================================================
@@ -8,3 +7,7 @@ from . import area_weighted
 from . import dasymetric
 from . import model
 from . import util
+from . import pycno
+
+from . import _version
+__version__ = _version.get_versions()['version']
