@@ -52,75 +52,6 @@ def _check_presence_of_crs(geoinput):
         raise KeyError("Geodataframe must have a CRS set before using this function.")
 
 
-def is_crs_utm(crs):
-    """
-    Determine if a CRS is a UTM CRS
-    Parameters
-    ----------
-    crs : dict or string or pyproj.CRS
-        a coordinate reference system
-    Returns
-    -------
-    bool
-        True if crs is UTM, False otherwise
-    """
-    if not crs:
-        return False
-    crs_obj = CRS.from_user_input(crs)
-    if (
-        crs_obj.coordinate_operation
-        and crs_obj.coordinate_operation.name.upper().startswith("UTM")
-    ):
-        return True
-    return False
-
-
-def project_gdf(gdf, to_crs=None, to_latlong=False):
-    """
-    lovingly copied from OSMNX <https://github.com/gboeing/osmnx/blob/master/osmnx/projection.py>
-
-    Project a GeoDataFrame to the UTM zone appropriate for its geometries'
-    centroid.
-    The simple calculation in this function works well for most latitudes, but
-    won't work for some far northern locations like Svalbard and parts of far
-    northern Norway.
-
-    Parameters
-    ----------
-    gdf : GeoDataFrame
-        the gdf to be projected
-    to_crs : dict or string or pyproj.CRS
-        if not None, just project to this CRS instead of to UTM
-    to_latlong : bool
-        if True, projects to latlong instead of to UTM
-
-    Returns
-    -------
-    GeoDataFrame
-    """
-    assert len(gdf) > 0, "You cannot project an empty GeoDataFrame."
-
-    # else, project the gdf to UTM
-    # if GeoDataFrame is already in UTM, just return it
-    if is_crs_utm(gdf.crs):
-        return gdf
-
-    # calculate the centroid of the union of all the geometries in the
-    # GeoDataFrame
-    avg_longitude = gdf.geometry.unary_union.centroid.x
-
-    # calculate the UTM zone from this avg longitude and define the UTM
-    # CRS to project
-    utm_zone = int(math.floor((avg_longitude + 180) / 6.0) + 1)
-    utm_crs = "+proj=utm +zone={} +ellps=WGS84 +datum=WGS84 +units=m +no_defs".format(
-        utm_zone
-    )
-
-    # project the GeoDataFrame to the UTM CRS
-    projected_gdf = gdf.to_crs(utm_crs)
-
-    return projected_gdf
-
 
 def h3fy(source, resolution=6, clip=False, return_geoms=True):
     """Generate a hexgrid geodataframe that covers the face of a source geodataframe.
@@ -147,8 +78,9 @@ def h3fy(source, resolution=6, clip=False, return_geoms=True):
     """
     # h3 hexes only work on polygons, not multipolygons
     if source.crs is None:
-        raise ValueError('source geodataframe must have a valid CRS set before using this function')
-    source = source.explode()
+        raise ValueError(
+            "source geodataframe must have a valid CRS set before using this function"
+        )
 
     orig_crs = source.crs
 
@@ -174,7 +106,6 @@ def h3fy(source, resolution=6, clip=False, return_geoms=True):
     if return_geoms and not hexagons.crs.equals(orig_crs):
         hexagons = hexagons.to_crs(orig_crs)
 
-
     return hexagons
 
 
